OC.L10N.register(
    "firstrunwizard",
    {
    "Get the apps to sync your files" : "برنامه ها را دریافت کنید تا فایل هایتان را همگام سازید",
    "Desktop client" : "نرم افزار دسکتاپ",
    "Android app" : "اپ اندروید",
    "iOS app" : "اپ iOS",
    "Connect your desktop apps to %s" : "اتصال برنامه دسکتاب خود به %s",
    "Access files via WebDAV" : "دسترسی فایل ها از طریق WebDAV"
},
"nplurals=2; plural=(n > 1);");
